From 958d5d8d83f6c5651e093614a4e5c3e5d2011abc Mon Sep 17 00:00:00 2001
From: Abhishek Singh <abhishekkumarsingh.cse@gmail.com>
Date: Mon, 18 Mar 2013 18:45:02 +0530
Subject: [PATCH] cmocka unittest for find_uid added

---
 Makefile.am                      |  22 ++++++++-
 src/tests/cmocka/test_find_uid.c | 104 +++++++++++++++++++++++++++++++++++++++
 2 files changed, 125 insertions(+), 1 deletion(-)
 create mode 100644 src/tests/cmocka/test_find_uid.c

diff --git a/Makefile.am b/Makefile.am
index 67e2bd1fb368e4472d5f6f816033ec7d81fc75d8..bc855a8f906cabc442ad2bd1d13e3ec253ee74eb 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -140,7 +140,8 @@ endif
 
 if HAVE_CMOCKA
     non_interactive_cmocka_based_tests = \
-	nss-srv-tests
+	nss-srv-tests \
+	test-find-uid
 endif
 
 check_PROGRAMS = \
@@ -1196,6 +1197,25 @@ nss_srv_tests_LDFLAGS = \
 nss_srv_tests_LDADD = \
     $(CMOCKA_LIBS) \
     libsss_util.la
+
+test_find_uid_DEPENDENCIES = \
+    $(ldblib_LTLIBRARIES)
+test_find_uid_SOURCES = \
+    src/tests/cmocka/test_find_uid.c \
+    src/util/find_uid.c \
+    src/util/atomic_io.c \
+    src/util/strtonum.c
+test_find_uid_CFLAGS = \
+    $(AM_CFLAGS) \
+    $(TALLOC_CFLAGS) \
+    $(DHASH_CFLAGS) \
+    --coverage 
+test_find_uid_LDADD = \
+    libsss_debug.la \
+    $(TALLOC_LIBS) \
+    $(DHASH_LIBS) \
+    $(CMOCKA_LIBS) \
+    libsss_util.la 
 endif
 
 noinst_PROGRAMS = pam_test_client
diff --git a/src/tests/cmocka/test_find_uid.c b/src/tests/cmocka/test_find_uid.c
new file mode 100644
index 0000000000000000000000000000000000000000..8d31a18153270a5548c5924c23c50884bdaa7b54
--- /dev/null
+++ b/src/tests/cmocka/test_find_uid.c
@@ -0,0 +1,104 @@
+/*
+    SSSD
+
+    find_uid - Utilities tests
+
+    Authors:
+        Abhishek Singh <abhishekkumarsingh.cse@gmail.com>
+
+    Copyright (C) 2009 Red Hat
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
+
+#include <stdarg.h>
+#include <stdlib.h>
+#include <stddef.h>
+#include <setjmp.h>
+#include <unistd.h>
+#include <sys/types.h>
+#include <cmocka.h>
+
+#include "util/find_uid.h"
+#include "tests/common.h"
+#include "dhash.h"
+
+void test_check_if_uid_is_active_success(void ** state)
+{
+    int ret;
+    uid_t uid;
+    bool result;
+
+    uid = getuid();
+
+    ret = check_if_uid_is_active(uid, &result);
+    assert_true(ret == EOK);
+    assert_true(result);
+}
+
+void test_check_if_uid_is_active_fail(void ** state)
+{
+    
+    int ret;
+    uid_t uid;
+    bool result;
+    
+    uid = (uid_t) -7;
+
+    ret = check_if_uid_is_active(uid, &result);
+    assert_true(ret == EOK);
+    assert_true(!result);
+}
+
+void test_get_uid_table(void ** state)
+{
+    int ret;
+    uid_t uid;
+    TALLOC_CTX *tmp_ctx;
+    hash_table_t *table;
+    hash_key_t key;
+    hash_value_t value;
+
+    tmp_ctx = talloc_new(NULL);
+    assert_true(tmp_ctx != NULL);
+
+    ret = get_uid_table(tmp_ctx, &table);
+    assert_true(ret == EOK);
+
+    uid = getuid();
+    key.type = HASH_KEY_ULONG;
+    key.ul = (unsigned long) uid;
+
+    ret = hash_lookup(table, &key, &value);
+    assert_true(ret == HASH_SUCCESS);
+    assert_true(hash_delete(table, &key) == HASH_SUCCESS);
+
+    uid = (uid_t) -7;
+    key.type = HASH_KEY_ULONG;
+    key.ul = (unsigned long) uid;
+
+    ret = hash_lookup(table, &key, &value);
+    assert_true(ret == HASH_ERROR_KEY_NOT_FOUND);
+
+    talloc_free(tmp_ctx);
+}
+
+int main(void)
+{
+    const UnitTest tests[] = {
+    unit_test(test_check_if_uid_is_active_success), unit_test(test_check_if_uid_is_active_fail),
+    unit_test(test_get_uid_table)};
+
+    return run_tests(tests);
+}
-- 
1.8.1.4

